Struct ZwpTabletPadGroupV2
pub struct ZwpTabletPadGroupV2 { /* private fields */ }wayland and Linux only.Expand description
a set of buttons, rings and strips
A pad group describes a distinct (sub)set of buttons, rings and strips present in the tablet. The criteria of this grouping is usually positional, eg. if a tablet has buttons on the left and right side, 2 groups will be presented. The physical arrangement of groups is undisclosed and may change on the fly.
Pad groups will announce their features during pad initialization. Between the corresponding zwp_tablet_pad_v2.group event and zwp_tablet_pad_group_v2.done, the pad group will announce the buttons, rings and strips contained in it, plus the number of supported modes.
Modes are a mechanism to allow multiple groups of actions for every element in the pad group. The number of groups and available modes in each is persistent across device plugs. The current mode is user-switchable, it will be announced through the zwp_tablet_pad_group_v2.mode_switch event both whenever it is switched, and after zwp_tablet_pad_v2.enter.
The current mode logically applies to all elements in the pad group, although it is at clients’ discretion whether to actually perform different actions, and/or issue the respective .set_feedback requests to notify the compositor. See the zwp_tablet_pad_group_v2.mode_switch event for more details.
See also the Event enum for this interface.
Implementations
impl ZwpTabletPadGroupV2
impl ZwpTabletPadGroupV2
pub fn destroy(&self)
pub fn destroy(&self)
destroy the pad object
Destroy the zwp_tablet_pad_group_v2 object. Objects created from this object are unaffected and should be destroyed separately.